16.141. cdist-type__ufw(7) — cdist 4.11.0 documentation

# 16.141. cdist-type__ufw(7)

## 16.141.1. NAME

cdist-type__ufw - Install the Uncomplicated FireWall

## 16.141.2. DESCRIPTION

Installs the Uncomplicated FireWall. Most modern distributions carry UFW in their main repositories, but on CentOS this type will automatically enable the EPEL repository.

Some global configuration can also be set with this type.

## 16.141.3. OPTIONAL PARAMETERS

state
  Either "enabled", "running", "present", or "absent". Defaults to "enabled", which registers UFW to start on boot.
logging
  Either "off", "low", "medium", "high", or "full". Will be passed to ufw logging. If not specified, logging level is not modified.
default_incoming
  Either "allow", "deny", or "reject". The default policy for dealing with ingress packets.
default_outgoing
  Either "allow", "deny", or "reject". The default policy for dealing with egress packets.
default_routed
  Either "allow", "deny", or "reject". The default policy for dealing with routed packets (passing through this machine).

## 16.141.4. EXAMPLES

    # Install UFW
    __ufw
    # Setup UFW with maximum logging and no restrictions on routed packets.
    __ufw --logging full --default_routed allow

## 16.141.5. SEE ALSO

ufw(8)

## 16.141.6. AUTHORS

Mark Polyakov <mark@markasoftware.com>

## 16.141.7. COPYING

Copyright (C) 2019 Mark Polyakov. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.